Index: trunk/pstamp/scripts/pstampparse.pl
===================================================================
--- trunk/pstamp/scripts/pstampparse.pl	(revision 28818)
+++ trunk/pstamp/scripts/pstampparse.pl	(revision 28878)
@@ -386,9 +386,10 @@
     $need_magic    = $proj_hash->{need_magic};
 
     # Temporary hack so that MOPS can get at non-magicked data
     my $allow_mops_unmagicked = 1;
     if ($allow_mops_unmagicked) {
         if ($product and (($product eq "mops-pstamp-results") or
-                          ($product eq "mops-pstamp-results2"))) {
+                          ($product eq "mops-pstamp-results2") or
+			  ($product eq "ifa-pstamp-results"))) {
             $need_magic = 0;
         }
@@ -386,9 +386,10 @@
     $need_magic    = $proj_hash->{need_magic};
 
-    # Temporary hack so that MOPS can get at non-magicked data
+    # Temporary hack so that IFA can get at non-magicked data
     my $allow_mops_unmagicked = 1;
     if ($allow_mops_unmagicked) {
